@@ -1,10 +1,11 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-09 13:42:11 mtw>
+# Last changed Time-stamp: <2017-06-10 18:19:30 michl>
 
 package Bio::ViennaNGS;
-
-use version; our $VERSION = qv('0.12_17');
-
+use Exporter;
+use version; our $VERSION = version->declare("v0.17.1");
+our @ISA = qw(Exporter);
+our @EXPORT = ($VERSION);
 1;
 
 =head1 NAME
@@ -20,7 +21,7 @@ pipelines. It covers various aspects of NGS data analysis, including
 (but not limited to) conversion of sequence annotation, evaluation of
 mapped data, expression quantification and visualization.
 
-The main Bio::ViennaNGS module is shipped with a complementary set of 
+The main Bio::ViennaNGS module is shipped with a complementary set of
 (sub)modules:
 
 =over
@@ -31,18 +32,18 @@ conversion of sequence annotation data.
 =item L<Bio::ViennaNGS::Bam>: Routines for high-level manipulation of
 BAM files.
 
-=item L<Bio::ViennaNGS::BamStat>: A L<Moose> based class for
-collecting mapping statistics.
-
-=item L<Bio::ViennaNGS::BamStatSummary>: A L<Moose> interface for
-processing L<Bio::ViennaNGS::BamStat> objects on a set of BAM files.
-
 =item L<Bio::ViennaNGS::Bed>: A L<Moose> interface for manipulation of
 genomic interval data in BED format.
 
+=item L<Bio::ViennaNGS::BedGraphEntry>: A L<Moose> interface for
+storing genomic cvoerage and interval data in bedGraph format.
+
 =item L<Bio::ViennaNGS::Expression>: An object oriented interface for
 read-count based gene expression analysis.
 
+=item L<Bio::ViennaNGS::ExtFeature>: A L<Moose> wrapper for extended
+BED6 entries.
+
 =item L<Bio::ViennaNGS::Fasta>: Routines for accessing genomic
 sequences implemented through a L<Moose> interface to
 L<Bio::DB::Fasta>.
@@ -52,15 +53,26 @@ L<Bio::DB::Fasta>.
 =item L<Bio::ViennaNGS::FeatureChain>: Yet another L<Moose> class for
 chaining gene annotation features.
 
+=item L<Bio::ViennaNGS::FeatureInterval>: A L<Moose> interface for
+handling elementary genomic intervals, corresponding to BED3.
+
+=item L<Bio::ViennaNGS::FeatureIO>: A L<Moose> interface for efficient
+input/output handling of genomic annotation formats.
+
 =item L<Bio::ViennaNGS::FeatureLine>: An abstract L<Moose> class for
 combining several L<Bio::ViennaNGS::FeatureChain> objects.
 
 =item L<Bio::ViennaNGS::MinimalFeature>: A L<Moose> interface for
-handling elementary gene annotation.
+handling elementary gene annotation, corresponding to BED4.
+
+=item L<Bio::ViennaNGS::Peak>: A L<Moose> interface for identification
+and characterization of peaks/enriched regions in RNA-seq data.
 
 =item L<Bio::ViennaNGS::SpliceJunc>: A collection of routines for
 alternative splicing analysis.
 
+=item L<Bio::ViennaNGS::Subtypes>: Moose subtypes for internal usage.
+
 =item L<Bio::ViennaNGS::Tutorial>: A comprehensive tutorial of the
   L<Bio::ViennaNGS> core routines with real-world NGS data.
 
@@ -110,9 +122,16 @@ bedGraph files, allowing additional annotation and automatic
 generation of bedGraph files which can easily be converted to big-type
 files for easy UCSC visualization.
 
-=item F<extend_bed.pl>: Extend genomic features in BED files by a
-certain number of nucleotides, either on both sides or specifically at
-the 5' or 3' end, respectively.
+=item F<bed2nt2aa.pl>: Provide nucleotide and amino acid sequences for
+BED6 intervals.
+
+=item F<bed62bed12.pl>: A simple BED6 -> BED12 converter.
+
+=item F<fasta_multigrep.pl>: Extract indivudual (whole) sequences from
+a multi Fasta file.
+
+=item F<fasta_subgrep.pl>: Extract subsequences from (multi) Fasta
+files.
 
 =item F<gff2bed.pl>: Convert RefSeq GFF3 annotation files to BED12
 format. Individual BED12 files are created for each feature type
@@ -131,8 +150,11 @@ organism for visualization. Based on L<this Genomewiki
 article|http://genomewiki.ucsc.edu/index.php/Building_a_new_genome_database>.
 
 =item F<normalize_multicov.pl>: Compute normalized expression data in
-TPM from (raw) read counts in bedtools multicov format. TPM reference:
-Wagner et al, Theory Biosci. 131(4), pp 281-85 (2012)
+RPKM and TPM from (raw) read counts in bedtools multicov format. TPM
+reference: Wagner et al, Theory Biosci. 131(4), pp 281-85 (2012).
+
+=item F<rnaseq_peakfinder.pl>: Find and characterize peaks/enriched
+regions of certain size and coverage in RNA-seq data.
 
 =item F<sj_visualizer.pl>: Convert splice junctions from mapped
 RNA-seq data in segemehl BED6 splice junction format to BED12 for easy
@@ -142,6 +164,10 @@ visualization in genome Browsers.
 junctions from RNA-seq data by intersecting them with annotated splice
 junctions.
 
+=item F<track_hub_constructor.pl>: Analogous to
+assembly_hub_constructor.pl, construct a Track Hub for an organism
+listed in the UCSC Genome Browser.
+
 =item F<trim_fastq.pl>: Trim sequence and quality string fields in a
 Fastq file by user defined length.
 
@@ -150,68 +176,30 @@ Fastq file by user defined length.
 =head1 DEPENDENCIES
 
 The L<Bio::ViennaNGS> modules and classes depend on a set of Perl
-modules, some of which are part of the Perl core distribution:
+modules, some of which are part of the Perl core distribution, most
+notably L<Bio::Perl> >= 1.00690001 and L<Bio::DB::Sam> >= 1.37.
+
+In addition, L<Bio::ViennaNGS> depends on third-party tools and
+libraries which are required for specific filtering and file format
+conversion tasks as well as for building internally used Perl modules:
 
 =over
 
-=item L<Bio::Perl> >= 1.00690001
+=item L<bedtools2|https://github.com/arq5x/bedtools2>
 
-=item L<Bio::DB::Sam> >= 1.37
+=item F<bedGraphToBigWig>, F<fetchChromSizes>, F<faToTwoBit> from the
+  L<UCSC Genome Browser
+  applications|http://hgdownload.cse.ucsc.edu/admin/exe>
 
-=item L<Bio::DB::Fasta>
+=item L<R|http://www.r-project.org/>
 
-=item L<Bio::Tools::GFF>
-
-=item L<File::Basename>
-
-=item L<File::Share>
-
-=item L<File::Temp>
-
-=item L<Path::Class>
-
-=item L<IPC::Cmd>
-
-=item L<Carp>
-
-=item L<Template>
-
-=item L<Moose>
-
-=item L<Moose::Util::TypeConstraints>
-
-=item L<namespace::autoclean>
-
-=item L<MooseX::Clone>
-
-=item L<MooseX::InstanceTracking>
-
-=item L<Tie::Hash::Indexed>
+=item samtools E<lt>=v0.1.19 for building L<Bio::DB::Sam>.
 
 =back
 
-In addition the following modules are required by the L<Bio::ViennaNGS> utilities:
-
-=over
-
-=item L<PerlIO::gzip>
-
-=item L<Math::Round>
-
-=item L<XML::Simple>
-
-=item L<Statistics::R>
-
-=back
-
-L<Bio::ViennaNGS> uses third-party tools for computing intersections
-of BED files: F<bedtools intersect> from the
-L<BEDtools|http://bedtools.readthedocs.org/en/latest/content/tools/intersect.html>
-suite is used to compute overlaps and F<bedtools sort> is used to sort
-BED output files. Make sure that those third-party utilities are
-available on your system, and that hey can be found and executed by
-the Perl interpreter. We recommend installing the latest version of
-L<BEDtools|https://github.com/arq5x/bedtools2> on your system.
+Please ensure that all third-party utilities are available on your
+system, and that hey can be found and executed by the Perl
+interpreter.
 
 =head1 SOURCE AVAILABILITY
 
@@ -229,7 +217,7 @@ analysis pipelines">
 
 I<Michael T. Wolfinger, Joerg Fallmann, Florian Eggenhofer and Fabian Amman>
 
-bioRxiv L<doi:10.1101/013011|http://dx.doi.org/10.1101/013011>.
+F1000Research 2015, 4:50 (doi: L<10.12688E<sol>f1000research.6157.2|http://dx.doi.org/10.12688/f1000research.6157.2>)
 
 =head1 NOTES
 
@@ -248,26 +236,34 @@ test Windows compatibility.
 
 =item L<Bio::ViennaNGS::Bam>
 
-=item L<Bio::ViennaNGS::BamStat>
-
-=item L<Bio::ViennaNGS::BamStatSummary>
-
 =item L<Bio::ViennaNGS::Bed>
 
+=item L<Bio::ViennaNGS::BedGraphEntry>
+
 =item L<Bio::ViennaNGS::Expression>
 
+=item L<Bio::ViennaNGS::ExtFeature>
+
 =item L<Bio::ViennaNGS::Fasta>
 
 =item L<Bio::ViennaNGS::Feature>
 
 =item L<Bio::ViennaNGS::FeatureChain>
 
+=item L<Bio::ViennaNGS::FeatureInterval>
+
+=item L<Bio::ViennaNGS::FeatureIO>
+
 =item L<Bio::ViennaNGS::FeatureLine>
 
 =item L<Bio::ViennaNGS::MinimalFeature>
 
+=item L<Bio::ViennaNGS::Peak>
+
 =item L<Bio::ViennaNGS::SpliceJunc>
 
+=item L<Bio::ViennaNGS::Subtypes>
+
 =item L<Bio::ViennaNGS::Tutorial>
 
 =item L<Bio::ViennaNGS::UCSC>
@@ -282,7 +278,7 @@ test Windows compatibility.
 
 =item Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
-=item Jörg Fallmann E<lt>fall@tbi.univie.ac.atE<gt>
+=item Joerg Fallmann E<lt>fall@tbi.univie.ac.atE<gt>
 
 =item Florian Eggenhofer E<lt>florian.eggenhofer@tbi.univie.ac.atE<gt>
 
@@ -292,7 +288,7 @@ test Windows compatibility.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015 Michael T. Wolfinger
+Copyright (C) 2014-2017 Michael T. Wolfinger
 E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
