@@ -1,19 +1,19 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-06 16:29:08 mtw>
+# Last changed Time-stamp: <2017-06-10 19:08:57 michl>
 
 package Bio::ViennaNGS::SpliceJunc;
 
+use Bio::ViennaNGS;
 use Exporter;
-use version; our $VERSION = qv('0.12_15');
 use strict;
 use warnings;
 use Data::Dumper;
-use Bio::ViennaNGS;
 use Bio::ViennaNGS::Fasta;
 use IPC::Cmd qw(can_run run);
 use File::Basename;
 use Path::Class;
 use Carp;
+use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 our @ISA = qw(Exporter);
 our @EXPORT = ();
@@ -30,7 +30,7 @@ our @EXPORT_OK = qw(bed6_ss_from_bed12 bed6_ss_from_rnaseq
 sub bed6_ss_from_bed12{
   my ($bed12,$dest,$window,$can,$fastaobjR) = @_;
   my ($i,$tr_name,$pos5,$pos3);
-  my ($splicesites,$c,$totalsj,$cansj) = 0x4;
+  my ($splicesites,$c,$totalsj,$cansj) = (0)x4;
   my @bedline = ();
   my $this_function = (caller(0))[3];
 
@@ -205,10 +205,13 @@ sub intersect_sj{
   my @junctions = ();
   my @transcript_beds = ();
   my %asj = (); # annotated splice junctions hash
-  my $bedtools = can_run('bedtools') or croak "bedtools not found";
-  my $sortBed  = can_run('sortBed') or croak "sortBed not found";
   my $this_function = (caller(0))[3];
 
+  my $bedtools = can_run('bedtools') or
+    croak "ERROR [$this_function] bedtools not found";
+  my $sortBed  = can_run('sortBed') or
+    croak "ERROR [$this_function] sortBed not found";
+
   croak "ERROR [$this_function] $p_annot does not exist\n"
     unless (-d $p_annot);
   croak "ERROR [$this_function] $p_mapped does not exist\n"
@@ -512,9 +515,9 @@ strand. In 5' to 3' direction of the forward strandm this junction
 reads CT->AC. A splice junction is canonical if its motif corresponds
 to one of the following cases:
 
-5'===]GT|CT....AG|AC[====3' ie GT->AG or CT->AC
-5'===]GC|CT....AG|GC[====3' ie GC->AG or CT->GC
-5'===]AT|GT....AC|AT[====3' ie AT->AC or GT->AT
+  5'===]GT|CT....AG|AC[====3' ie GT->AG or CT->AC
+  5'===]GC|CT....AG|GC[====3' ie GC->AG or CT->GC
+  5'===]AT|GT....AC|AT[====3' ie AT->AC or GT->AT
 
 =back
 
@@ -555,7 +558,7 @@ Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2015-2017 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
