@@ -1,25 +1,32 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-06 16:29:26 mtw>
+# Last changed Time-stamp: <2017-06-10 19:11:36 michl>
 
 package Bio::ViennaNGS::UCSC;
 
+use Bio::ViennaNGS;
 use Exporter;
-use version; our $VERSION = qv('0.12_15');
 use strict;
 use warnings;
 use Template;
 use Cwd;
 use File::Basename;
+use File::Find;
 use IPC::Cmd qw(can_run run);
 use File::Share ':all';
 use Path::Class;
 use Data::Dumper;
 use Carp;
-use Bio::ViennaNGS::Util qw(fetch_chrom_sizes);
+use Bio::ViennaNGS::Util qw(fetch_chrom_sizes bed2bigBed);
+use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 our @ISA = qw(Exporter);
 
-our @EXPORT_OK = qw( make_assembly_hub make_track_hub );
+our @EXPORT_OK = qw( make_assembly_hub make_track_hub retrieve_color
+make_track make_multi_bigwig_container_track
+make_bigwig_container_track retrieve_bigwig_tracks
+retrieve_bigbed_url_tracks parse_fasta_header valid_ncbi_accession
+modify_fasta_header make_group retrieve_chromosome_size
+write_chromosome_size_file convert_tracks);
 
 our @EXPORT = ();
 
@@ -39,10 +46,6 @@ sub make_assembly_hub{
   croak ("ERROR [$this_function]: no URL (network location for upload to UCSC) provided") 
     unless(defined $baseURL);
 
-  if (defined $log){
-    open(LOG, ">>", $log) or croak "$!";
-  }
-
   unless ($baseURL =~ /\/$/) { $baseURL .= "/"; }
 
   my $tmp_path = dist_file('Bio-ViennaNGS', "hub.txt" );
@@ -54,9 +57,6 @@ sub make_assembly_hub{
   my $faToTwoBit = can_run('faToTwoBit') or
     croak ("ERROR [$this_function] faToTwoBit is not installed!");
 
-  my $bedToBigBed = can_run('bedToBigBed') or
-    croak ("ERROR [$this_function] bedToBigBed is not installed!");
-
   # bedfiles path
   my $parsedHeaderRef = parse_fasta_header($fasta_path,$this_function);
   my @parsedHeader = @$parsedHeaderRef;
@@ -70,9 +70,12 @@ sub make_assembly_hub{
   my $genome_assembly_directory = dir($assembly_hub_directory,$genome_assembly_name);
   mkdir $assembly_hub_directory;
   mkdir $genome_assembly_directory;
+
   if (defined $log){
+    open(LOG, ">>", $log) or croak "$!";
     print LOG "LOG Base directory:          $assembly_hub_directory\n";
     print LOG "LOG Assembly Hub directory:  $genome_assembly_directory\n";
+    close(LOG);
   }
 
   #2-bit fasta file conversion
@@ -80,7 +83,12 @@ sub make_assembly_hub{
   modify_fasta_header($fasta_path,$fa_modified,$accession);
   my $twoBit = file($genome_assembly_directory, $accession.".2bit");
   my $fastaToTwobit_cmd = "$faToTwoBit $fa_modified $twoBit";
-  if (defined $log){  print LOG "LOG [$this_function] $fastaToTwobit_cmd\n";}
+
+  if (defined $log){
+    open(LOG, ">>", $log) or croak "$!";
+    print LOG "LOG [$this_function] $fastaToTwobit_cmd\n";
+    close(LOG);
+  }
 
   my( $success, $error_message, $full_buf, $stdout_buf, $stderr_buf ) =
     run( command => $fastaToTwobit_cmd, verbose => 0 );
@@ -176,15 +184,15 @@ sub make_assembly_hub{
     my $chromosome_size = retrieve_chromosome_size($fasta_path);
     my $chromosome_size_filepath = file($genome_assembly_directory,"$accession.chrom.sizes");
     write_chromosome_size_file($chromosome_size_filepath,$accession,$chromosome_size);
-    convert_tracks($filesdir, $genome_assembly_directory, $accession, $bedToBigBed, $chromosome_size_filepath);
+    convert_tracks($filesdir, $genome_assembly_directory, $chromosome_size_filepath, $log);
     my @trackfiles = retrieve_tracks($genome_assembly_directory, $baseURL, $assembly_hub_name, $accession);
-    
+
     foreach my $track (@trackfiles){
       my $trackString = make_track(@$track);
       $tracksList .= $trackString;
     }
   }
-  
+
   #big wigs
   my $bigwig_tracks_string = "";
   unless($big_wig_ids=~/^-$/){
@@ -202,13 +210,14 @@ sub make_assembly_hub{
     croak "Template process failed: ", $template->error(), "\n";
 
   if (defined $log){
+    open(LOG, ">>", $log) or croak "$!";
     print LOG "LOG Assembly Hub created\n";
     close(LOG);
   }
 }
 
 sub make_track_hub{
-  my ($species, $filesdir, $basedir, $baseURL, $chrom_sizes_file, $big_wig_ids, $log) = @_;
+  my ($species, $basedir, $baseURL, $big_bed_ids, $big_wig_ids, $log) = @_;
   my ($basename,$dir,$ext);
   my $this_function = (caller(0))[3];
 
@@ -235,9 +244,6 @@ sub make_track_hub{
   my $faToTwoBit = can_run('faToTwoBit') or
     croak ("ERROR [$this_function] faToTwoBit is not installed!");
 
-  my $bedToBigBed = can_run('bedToBigBed') or
-    croak ("ERROR [$this_function] bedToBigBed is not installed!");
-
   # create track hub directory structure
   my $track_hub_name = "trackHub";
   my $track_hub_directory = dir($basedir, $track_hub_name);
@@ -291,24 +297,12 @@ sub make_track_hub{
     croak "Template process failed: ", $template->error(), "\n";
 
   my $tracksList;
-  #Bigbeds are only created from infolder
-  unless($filesdir =~ /-/){
-    if(-e $chrom_sizes_file){
-      convert_tracks($filesdir, $genome_assembly_directory, $species, $bedToBigBed, $chrom_sizes_file);
-    }else{
-      my $chromosome_sizes = fetch_chrom_sizes($species);
-      my $chromosome_size_filepath = file($genome_assembly_directory,"$species.chrom.sizes");
-      write_chromosome_sizes_file($chromosome_size_filepath,$chromosome_sizes);
-      convert_tracks($filesdir, $genome_assembly_directory, $species, $bedToBigBed, $chromosome_size_filepath);
-    }
-    my @trackfiles = retrieve_tracks($genome_assembly_directory, $baseURL, $track_hub_name, $species);
-
-    #big beds
-    foreach my $track (@trackfiles){
-      my $trackString = make_track(@$track);
-      $tracksList .= $trackString;
-    }
+  #bigbeds are only created from urls
+  my $bigbeds_tracks_string = "";
+  unless($big_bed_ids=~/^-$/){
+    $bigbeds_tracks_string = retrieve_bigbed_url_tracks($genome_assembly_directory, $baseURL, $track_hub_name, $big_bed_ids);
   }
+  $tracksList .= $bigbeds_tracks_string;
   #big wigs
   my $bigwig_tracks_string = "";
   unless($big_wig_ids=~/^-$/){
@@ -332,19 +326,27 @@ sub make_track_hub{
 }
 
 sub convert_tracks{
-  my ($filesdir,$genome_assembly_directory,$accession,$bedToBigBed,$chromosome_size_filepath) = @_;
-  my $currentDirectory = getcwd;
-  chdir $filesdir or croak $!;
-  my @bedfiles = <*.bed>;
+  my ($filesdir,$genome_assembly_directory,$chromosome_size_filepath,$log) = @_;
+  my $this_function = (caller(0))[3];
+  my @bedfiles = ();
+
+  find( sub {
+	  return unless -f;
+	  return unless /\.bed$/;
+	  push @bedfiles, $File::Find::name;
+	} , $filesdir);
+
+  if (defined $log){
+    open(LOG, ">>", $log) or croak $!;
+    foreach my $bedfile (@bedfiles){
+      print LOG "LOG [$this_function] found file $bedfile\n";
+    }
+    close(LOG);
+  }
+
   foreach my $bedfile (@bedfiles){
-    my $bed_file_path = file($filesdir,$bedfile);
-    my $filename = $bedfile;
-    $filename =~ s/.bed$//;
-    my $bigbed_file = $filename . ".bb";
-    my $bigbed_file_path = file($genome_assembly_directory,$bigbed_file);
-    `$bedToBigBed $bed_file_path $chromosome_size_filepath $bigbed_file_path`;
+    bed2bigBed($bedfile,$chromosome_size_filepath,$genome_assembly_directory,$log);
   }
-  chdir $currentDirectory or croak $!;
   return 1;
 }
 
@@ -359,15 +361,13 @@ sub retrieve_tracks{
     my $filename = $trackfile;
     $filename =~ s/.bb$//;
     my @filenameSplit = split(/\./, $filename);
-    my $fileaccession = $filenameSplit[0];
-    my $tag = $filenameSplit[1];
-    my $id = lc($tag);
-    my $track = "refseq_" . $id;
+    my $id = lc($filename);
+    my $tag = $id;
+    my $track = $id . "_bed";
     my $dir = dir($baseURL,$assembly_hub_name,$accession);
-    #my $bigDataUrl = file($dir, $trackfile);
     my $bigDataUrl = file($trackfile);
-    my $shortLabel = "RefSeq " . $tag;
-    my $longLabel = "RefSeq " . $tag;
+    my $shortLabel = $id;
+    my $longLabel = $id;
     my $type = "bigBed 12 .";
     my $autoScale = "off";
     my $bedNameLabel = "Gene Id";
@@ -385,6 +385,37 @@ sub retrieve_tracks{
   return @tracks;
 }
 
+sub retrieve_bigbed_url_tracks{
+  my ($directoryPath,$baseURL,$assembly_hub_name,$bigbedpaths) = @_;
+  my $currentDirectory = getcwd;
+  chdir $directoryPath or croak $!;
+  my @big_bed_array = split('#', $bigbedpaths);
+  my $bigbedtracks = "";
+  my $counter = 0;
+  foreach my $bigbed_entry (@big_bed_array){
+      #construct single big bed track
+      my ($basename,$dir,$ext) = fileparse($bigbed_entry,qr/\..*/);
+      my $id = lc($basename);
+      my $tag = $id . $ext . "_bed";
+      my $track = $id . $ext  ."_bed";
+      my $bigDataUrl = $bigbed_entry;
+      my $shortLabel = $id;
+      my $longLabel = $id;
+      my $type = "bigBed 12 .";
+      my $autoScale = "off";
+      my $bedNameLabel = "Gene Id";
+      my $searchIndex = "name";
+      my $colorByStrand = retrieve_color($counter);
+      my $visibility = "pack";
+      my $group = "annotation";
+      my $priority = "10";
+      my $track_string = make_track($tag, $track, $bigDataUrl, $shortLabel, $longLabel, $type, $autoScale, $bedNameLabel, $searchIndex, $colorByStrand, $visibility, $group, $priority);
+      $bigbedtracks .= $track_string;
+      $counter++;
+  }
+  chdir $currentDirectory or croak $!;
+  return $bigbedtracks;
+}
 
 sub retrieve_bigwig_tracks{
   my ($directoryPath,$baseURL,$assembly_hub_name,$accession,$bigwigpaths) = @_;
@@ -396,30 +427,14 @@ sub retrieve_bigwig_tracks{
     if($bigwig_entry=~/,/){
       #multi bigwig container detected
       my @big_wig_pair = split(',', $bigwig_entry);
-      my $pos_wig;
-      my $neg_wig;
-      if ($big_wig_pair[0] =~ /\.pos\./){
-        $pos_wig = $big_wig_pair[0];
-      }elsif($big_wig_pair[1] =~ /\.pos\./){
-        $pos_wig = $big_wig_pair[1];
-      }else{
-        my $this_function = (caller(0))[3];
-        croak ("ERROR [$this_function] \no positive big wig file for container provided\n");
-      }
-      if ($big_wig_pair[0] =~ /\.neg\./){
-        $neg_wig = $big_wig_pair[0];
-      }elsif($big_wig_pair[1] =~ /\.neg\./){
-        $neg_wig = $big_wig_pair[1];
-      }else{
-        my $this_function = (caller(0))[3];
-        croak ("ERROR [$this_function] \no negative big wig file for container provided\n");
-      }
+      my $pos_wig=$big_wig_pair[0];
+      my $neg_wig=$big_wig_pair[1];
       my ($basename1,$dir1,$ext1) = fileparse($pos_wig,qr/\..*/);
       my ($basename2,$dir2,$ext2) = fileparse($pos_wig,qr/\..*/);
       #construct container
       my $id = lc($basename1);
-      my $tag = $id;
-      my $track = $id;
+      my $tag = $id . "_bw";
+      my $track = $id . "_bw";
       my $shortLabel = $tag;
       my $longLabel = $tag;
       my $type = "bigWig";
@@ -449,11 +464,11 @@ sub retrieve_bigwig_tracks{
       my $track2_string = make_bigwig_container_track($track2, $bigDataUrl2, $shortLabel2, $longLabel2, $type2, $parent2, $color2);
       $bigwigtracks .= $track2_string;
     }else{
-      #construct single wig
+      #construct single big wig track
       my ($basename,$dir,$ext) = fileparse($bigwig_entry,qr/\..*/);
       my $id = lc($basename);
-      my $tag = $id;
-      my $track = $id;
+      my $tag = $id . "_bw";
+      my $track = $id . "_bw";
       my $bigDataUrl = $bigwig_entry;
       my $shortLabel = $tag;
       my $longLabel = $tag;
@@ -537,13 +552,13 @@ sub make_bigwig_track{
 
 sub valid_ncbi_accession{
   # receives a NCBI accession ID, with or without version number
-  # returns NCBI accession ID without version number
+  # checks for validity and returns the accession number as is
   my $acc = shift;
   if ($acc =~ /^(N[CST]\_\d{6})\.\d+?$/){
-    return $acc; # NCBI accession ID without version
+    return $acc;
   }
   elsif ($acc =~ /^(N[CST]\_\d{6})$/){
-    return $1; # NCBI accession ID without version
+    return $1;
   }
   else {
     return 0;
@@ -552,33 +567,27 @@ sub valid_ncbi_accession{
 
 sub parse_fasta_header{
   my $filepath = shift;
-  my $this_function = shift;
-  open my $file, '<', "$filepath";
+  my $this_function = (caller(0))[3];
+  open my $file, '<', "$filepath" or die $!;
   my $fastaheader = <$file>;
   chomp $fastaheader;
   close $file;
+  my @ids = ();
   #>gi|556503834|ref|NC_000913.3| Escherichia coli str. K-12 substr. MG1655
   if($fastaheader=~/^>gi/){
-    print LOG "#NCBI fasta header detected\n";
     my @headerfields = split(/\|/, $fastaheader);
     my $accession = $headerfields[3];
     my $scientificName = $headerfields[4];
-    my @ids;
     push(@ids,$accession);
     push(@ids,$scientificName);
     return \@ids;
   }else{
     $fastaheader=~s/^>//;
-    if(valid_ncbi_accession($fastaheader)){
-      print LOG "#Header contains just valid NCBI accession number\n";
-      my @ids;
-      push(@ids,$fastaheader);
-      push(@ids,"scientific name not set");
-      return \@ids;
-    }else{
-      print LOG "#No valid accession/ ncbi header\n";
-      croak ("ERROR [$this_function] \$fasta_path does not contain a valid accession/ ncbi header\n");
-    }
+    carp "INFO [$this_function] It looks like your input Fasta header does not contain a valid NCBI accession number. Continuing with:\n $fastaheader\n"
+      unless ( valid_ncbi_accession($fastaheader) );
+    push(@ids,$fastaheader);
+    push(@ids,"scientific name not set");
+    return \@ids;
   }
 }
 
@@ -587,7 +596,7 @@ sub write_chromosome_size_file{
   my $chromosome_name = shift;
   my $chromosome_size = shift;
   my $entry = $chromosome_name . "\t" . $chromosome_size . "\n";
-  open CHROMFILE, '>', "$filepath";
+  open CHROMFILE, '>', "$filepath" or die $!;
   print CHROMFILE $entry;
   close CHROMFILE;
   return 1;
@@ -597,7 +606,7 @@ sub write_chromosome_sizes_file{
   my $filepath = shift;
   my $chromosome_sizes_reference = shift;
   my %chromosome_sizes = %{$chromosome_sizes_reference};
-  open CHROMFILE, '>', "$filepath";
+  open CHROMFILE, '>', "$filepath" or die $!;
   foreach my $chromosome_name ( keys %chromosome_sizes){
     my $chromosome_size = $chromosome_sizes{$chromosome_name};
     my $entry = $chromosome_name . "\t" . $chromosome_size . "\n";
@@ -662,11 +671,9 @@ integration.
 
 =head1 DESCRIPTION
 
-ViennaNGS::UCSC is a Perl extension for managing routine tasks with the
-UCSC Genome Browser. It comes with a set of utilities that serve as
-reference implementation of the routines implemented in the library. All
-utilities are located in the 'scripts' folder.
-The main functionality is provided by the make_assembly_hub function.
+L<Bio::ViennaNGS::UCSC> facilitates routine tasks for automatic
+visualization of next-generation sequencing data in the UCSC Genome
+Browser.
 
 =head2 EXPORT
 
@@ -678,22 +685,40 @@ Variables:
 
 =head3 make_assembly_hub()
 
-Build assembly hubs for the UCSC genome browser.
-This function takes 4 parameters:
-1. absolute path of input fasta file(e.g. /home/user/input.fa)
-2. path to the ouput directory (e.g. /home/user/assemblyhubs/)
-3. base URL where the output folder will be placed for upload to the UCSC genome browser (e.g. http://www.foo.com/folder/)
-4. path for the log file (/home/user/logs/assemblyhubconstructionlog)
+Build an UCSC Genome Browser Assembly Hub. This function takes 4
+parameters:
+
+=over
+
+=item 1 absolute path of input fasta file(e.g. /home/user/input.fa)
+
+=item 2 path to the ouput directory (e.g. /home/user/assemblyhubs/)
+
+=item 3 base URL under which the new Assembly Hub will be available on
+the Internet, e.g. http://www.foo.com/folder/. The generated Assembly
+Hub files must be copied to the corresponding file system location on
+the Web Server and the URL readable for the UCSC Genome Browser server.
+
+=item 4 path for the log file (/home/user/logs/assemblyhubconstructionlog)
+
+=back
 
 =head3 make_track_hub()
 
 Build track hubs for the UCSC genome browser.
 This function takes 4 parameters:
-1. chromosome id as used in existing ucsc assembly hub (e.g. chr1)
-2. path to the ouput directory (e.g. /home/user/assemblyhubs/)
-3. base URL where the output folder will be placed for upload to the UCSC genome browser (e.g. http://www.foo.com/folder/)
-4. path for the log file (/home/user/logs/assemblyhubconstructionlog)
 
+=over
+
+=item 1 chromosome id as used in existing ucsc assembly hub (e.g. chr1)
+
+=item 2 path to the ouput directory (e.g. /home/user/assemblyhubs/)
+
+=item 3 base URL where the output folder will be placed for upload to the UCSC genome browser (e.g. http://www.foo.com/folder/)
+
+=item 4 path for the log file (/home/user/logs/assemblyhubconstructionlog)
+
+=back
 
 =head1 SEE ALSO
 
@@ -715,7 +740,7 @@ This function takes 4 parameters:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Michael T. Wolfinger, E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2014-2017 Michael T. Wolfinger, E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
